@@ -27,6 +27,7 @@ from embedops_cli.eo_types import (
     UnknownDockerException,
 )
 from embedops_cli.api.default_api import DefaultApi
+from embedops_cli.config import settings
 
 _logger = logging.getLogger(__name__)
 
@@ -39,9 +40,9 @@ def get_auth_token(secrets_file=user_secrets) -> str:
     key = None
     if not os.path.exists(secrets_file):
         return key
-    settings = Dynaconf(SETTINGS_FILES=[secrets_file])
+    secrets_file_settings = Dynaconf(SETTINGS_FILES=[secrets_file])
     try:
-        key = settings.EMBEDOPS_AUTH_TOKEN
+        key = secrets_file_settings.EMBEDOPS_AUTH_TOKEN
     except AttributeError:
         # eat the attribute error because it's expected when the user has not logged in
         pass
@@ -76,9 +77,9 @@ def get_registry_token(secrets_file=user_secrets):
     """Retrieve the Auth0 token from user secrets"""
     if not os.path.exists(secrets_file):
         raise UnauthorizedUserException
-    settings = Dynaconf(SETTINGS_FILES=[secrets_file])
+    secrets_file_settings = Dynaconf(SETTINGS_FILES=[secrets_file])
     try:
-        registry_token = settings.EMBEDOPS_GL_TOKEN
+        registry_token = secrets_file_settings.EMBEDOPS_GL_TOKEN
     except AttributeError as exc:
         raise UnauthorizedUserException from exc
     if not registry_token:
@@ -200,7 +201,7 @@ def check_token():
 
 def get_user_client():
     """Get a client for the embedops API as the currently signed in user"""
-    api_host = "https://app.embedops.io"  # TODO: get config.py working in CLI
+    api_host = settings.get("host")  # TODO: get config.py working in CLI
     auth_token = get_auth_token()
     configuration = Configuration()
     configuration.host = f"{api_host}/api/v1"
